#! /bin/bash
#
# This script checks teh configuration of Loway Uniloader
#

VERSION=24.11.1-642f919


die() {
	echo "Error checking Uniloader settings: ${1}"
	exit 1
}

unitstatus() {

	unit_name="${1}.service"

	# Check if the unit is active
	if systemctl is-active "$unit_name" &> /dev/null; then
		echo -n "Unit $unit_name is active and "
	else
		echo -n "Unit $unit_name is *not* active and "
	fi

	# Check the unit's restart behavior
	if systemctl is-enabled "$unit_name" &> /dev/null; then
	    echo "is set to restart on boot."
	else
	    echo "is not set to restart on boot."
	fi
}


banner() {
	unitname="$1"
	descr="$2"

	echo 
	echo =====================================================================
	echo $2
	echo
	echo - Configuration loaded from: /etc/${unitname}
	echo -n "- "
	unitstatus "$unitname"
	echo =====================================================================
	echo
}

#
# checking
#

for BINARY in echo uniloader systemctl
do
	if [ "$( which "${BINARY}" > /dev/null 2>&1 ; echo "${?}" )" != "0" ]
	then
		die "Missing "${BINARY}""
	fi
done


# Checking uniloader upload
check_upload() {
	banner "uniloader" "Checking upload credentials" 
	. /etc/uniloader
	uniloader test upload --uri "${URI}" --login "${LOGIN}" --pass "${UPASSWD}" --token "${TOKEN}"  --timeout 5
	if [ $? -eq 0 ]; then
	  echo "-----------"
	else
	  die "Command 'uniloader' failed with exit status $?"
	fi

	unitstatus "uniloader"
}


# Checking uniloader upload
check_ami() {
	banner "unitracker" "Checking AMI credentials" 

	. /etc/unitracker
	uniloader test ami  --host "${AMIHOST}" --port "${AMIPORT}" --login "${AMIUSER}" --secret "${AMISECRET}"
	if [ $? -eq 0 ]; then
	  echo "-----------"
	else
	  die "Command 'uniloader' failed with exit status $?"
	fi

	unitstatus "uniloader"
	
}

check_fsw() {
	banner "uniloader-freeswitch" "Checking ESW credentials"

	. /etc/uniloader-freeswitch
	uniloader test fsw-esl --host "${HOST}" --port "${PORT}" --auth "${AUTH}"
	if [ $? -eq 0 ]; then
	  echo "-----------"
	else
	  die "Command 'uniloader' failed with exit status $?"
	fi

}

check_av() {
	banner "audiovault" "Checking Audiovault"

	. /etc/audiovault
	uniloader test audiovault --public-url "${PUBLICURL}" --token "${TOKEN}" -c unknown.call -t 10000000
	if [ $? -eq 0 ]; then
	  echo "-----------"
	else
	  die "Command 'uniloader' failed with exit status $?"
	fi

}


#
#
#

case "$1" in
"upload")
  check_upload
  ;;
"unitracker")
  check_ami
  ;;
"audiovault")
  check_av
  ;;
"freeswitch")
  check_fsw
  ;;

"all")
  check_upload
  check_ami
  check_av
  check_fsw
  ;;
*)
  echo "Error: $0 [all|upload|unitracker|audiovault|freeswitch]"
  echo "Uniloader version: "
  uniloader -v
  exit 1
  ;;
esac

